@@ -130,6 +130,13 @@ SETTING_GK_FOCUS_TASKS = 'focus-tasks'
 SETTING_GK_TOGGLE_HIDDEN = 'toggle-hidden'
 SETTING_GK_TOGGLE_DARK = 'toggle-dark-mode'
 SETTING_GK_DELEGATE = 'delegate'
+SETTING_GK_INC_PRIO = 'prio-up'
+SETTING_GK_DEC_PRIO = 'prio-down'
+SETTING_GK_REM_PRIO = 'prio-none'
+SETTING_GK_SET_PRIOA = 'prio-a'
+SETTING_GK_SET_PRIOB = 'prio-b'
+SETTING_GK_SET_PRIOC = 'prio-c'
+SETTING_GK_SET_PRIOD = 'prio-d'
 
 TF_SELECTION = 'selection'
 TF_NUMBER = 'nr'
